========
ARSPY
========

|Build Status|
|Coverage_|
|Pypi_|

Adaptive Rejection Sampling for Python

Install
=======

Simply run::

   pip3 install ARSpy

.. |Build Status| image:: https://travis-ci.org/MFreidank/pyARS.svg?branch=master
    :target: https://travis-ci.org/MFreidank/pyARS

.. |Coverage_| image:: https://coveralls.io/repos/github/MFreidank/pyARS/badge.svg
   :target: https://coveralls.io/github/MFreidank/pyARS
   :alt: Coverage

.. |Pypi_| image:: https://badge.fury.io/py/ARSpy.svg
    :target: https://badge.fury.io/py/ARSpy
